weather.ini - format du fichier de configuration — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Guides utilisateur »

# weather.ini - format du fichier de configuration

Presque toute la configuration de pywws est fait via un seul fichier dans le répertoire de donnée: weather.ini. Ce fichier a été structuré de manière similaire aux fichiers INI de Microsoft Windows. Il est divisé en ‘sections’, qui contiennent un nom d’entrée ‘nom = valeur’. L’ordre d’apparition des sections n’a pas d’importance.

Any plain text editor can be used to do edit the file. (Don’t try to edit it while any other pywws software is running.) In many cases pywws will initialise the entries to sensible values.

Another file, status.ini, is used to store some information that pywws uses internally. It is described at the end of this document. In normal use you should not need to edit it.

Les sections suivantes sont présentement utilisées:

> - config: diverses configuration système.
> - paths: dossiers dans lesquels sont emmagasinés les gabarits, etc.
> - live: tâches à accomplir à chaque 48 secondes.
> - logged: tâches à accomplir chaque fois que la station enregistre une lecture.
> - hourly: tâches à réaliser à chaque heure.
> - 12 hourly: tâches à réaliser à chaque 12 heures.
> - daily: tâches à faire chaque jour.
> - ftp: configuration pour le téléversement du un site web.
> - twitter: configuration pour poster sur Twitter.
> - underground, metoffice, temperaturnu etc: configuration pour poster sur ces ‘services’.

## config: diverses configuration système

    [config]
    ws type = 1080
    day end hour = 21
    gnuplot encoding = iso_8859_1
    template encoding = iso-8859-1
    language = en
    logdata sync = 1
    rain day threshold = 0.2

`ws type` is the “class” of weather station. It should be set to `1080` for most weather stations, or `3080` if your station console displays solar illuminance.

`day end hour` est la fin du “jour météorologique”, selon l’heure locale sans tenir compte de l’heure d’été. Généralement, les valeurs sont 21, 9, ou 24.

`gnuplot encoding` est l’encodage de texte utilisé lors du tracé de graphes. La valeur par défaut est `iso_8859_1` permettant le symbole des degrés, fort utile dans une application météorologique! D’autres valeurs peuvent être nécessaire si votre langue comporte des caractères accentués. Les valeurs possible dépendent de votre installation gnuplot, quelques expérimentations peuvent donc être nécessaire.

`template encoding` is the text encoding used for templates. The default value is `iso-8859-1`, which is the encoding used in the example templates. If you create templates with a different character set, you should change this value to match your templates.

`language` is used to localise pywws. It’s optional, as pywws usually uses the computer’s default language as set by the LANG environment variable. The available languages are those in the `translations` subdirectory of your pywws installation. If you set any other language, pywws will fall back to using English.

`logdata sync` configure la qualité de la synchronisation utilisé par pywws.LogData. Fixer à 0 pour rapide & imprécis ou 1 pour plus lent, mais précis.

`rain day threshold` is the amount of rain (in mm) that has to fall in one day for it to qualify as a rainy day in the monthly summary data.

## paths: dossiers dans lesquels sont emmagasinés les gabarits, etc.

    [paths]
    templates = /home/$USER/weather/templates/
    graph_templates = /home/$USER/weather/graph_templates/
    user_calib = /home/jim/weather/modules/usercalib
    work = /tmp/weather

Ces trois entrées spécifient où sont emmagasinés vos gabarits de texte et de graphes, où doivent être créé les fichiers temporaires, et la localisation de votre module de calibration (si utilisé).

## live: tâches à accomplir à chaque 48 secondes

    [live]
    services = ['underground']
    twitter = []
    text = []
    plot = []
    yowindow = /home/jim/data/yowindow.xml

Cette section spécifie les tâche devant être effectuées pour chaque échantillonnage pendant la ‘journalisation temps réel’, c.à.d. chaque 48 secondes. Il est peu probable que vous vouliez faire autre chose que le téléversement à Weather Underground ou la mise-à-jour du fichier YoWindow aussi souvent.

`services` est une liste de ‘services’ auxquels envoyer vos données. Chaque service listé doit avoir un fichier de configuration dans le dossier `pywws/services/`. Voir pywws.toservice pour plus de détails.

`twitter` est une liste de gabarit texte à traiter avant de les poster sur Twitter.

`text` et `plot` sont des listes de gabarits texte et graphe à traiter et à téléverser sur votre site web.

`yowindow` indique le chemin complet du fichier au format xml à générer pour le widget YoWindow weather (voir http://yowindow.com/). Si vous n’employez pas YoWindow, omettez cette entrée.

## logged: tâches à accomplir chaque fois que la station enregistre une lecture

    [logged]
    services = ['underground', 'metoffice']
    twitter = ['tweet.txt']
    text = []
    plot = []

Cette section spécifie les tâche devant être réalisées chaque fois qu’une donnée est lue en mode ‘temps réel’ ou chaque fois qu’une tâche horaire cron est exécutée.

`services` est une liste de ‘services’ auxquels envoyer vos données. Chaque service listé doit avoir un fichier de configuration dans le dossier `pywws/services/`. Voir pywws.toservice pour plus de détails.

`twitter` est une liste de gabarit texte à traiter avant de les poster sur Twitter.

`text` et `plot` sont des listes de gabarits texte et graphe à traiter et à téléverser sur votre site web.

## hourly: tâches à réaliser à chaque heure

    [hourly]
    services = []
    twitter = ['tweet.txt']
    text = ['24hrs.txt', '6hrs.txt', '7days.txt', 'feed_hourly.xml', 'allmonths.txt']
    plot = ['7days.png.xml', '24hrs.png.xml', 'rose_12hrs.png.xml']

Cette section spécifie les tâches à réaliser à chaque heure en mode ‘temps réel’ ou exécutées en tant que tâche horaire cron.

`services` est une liste de ‘services’ auxquels envoyer vos données. Chaque service listé doit avoir un fichier de configuration dans le dossier `pywws/services/`. Voir pywws.toservice pour plus de détails.

`twitter` est une liste de gabarit texte à traiter avant de les poster sur Twitter.

`text` et `plot` sont des listes de gabarits texte et graphe à traiter et à téléverser sur votre site web.

## 12 hourly: tâches à réaliser à chaque 12 heures

    [12 hourly]
    services = []
    twitter = []
    text = []
    plot = []

Cette section spécifie les tâches à réaliser à chaque 12 heures en mode ‘temps réel’ exécutées en tant que tâche horaire cron. Utilisez pour des choses qui ne changent pas très souvent, tel que les graphes mensuels.

`services` est une liste de ‘services’ auxquels envoyer vos données. Chaque service listé doit avoir un fichier de configuration dans le dossier `pywws/services/`. Voir pywws.toservice pour plus de détails.

`twitter` est une liste de gabarit texte à traiter avant de les poster sur Twitter.

`text` et `plot` sont des listes de gabarits texte et graphe à traiter et à téléverser sur votre site web.

## daily: tâches à faire à chaque 24 heures

    [daily]
    services = []
    twitter = []
    text = ['feed_daily.xml']
    plot = ['2008.png.xml', '2009.png.xml', '2010.png.xml', '28days.png.xml']

Cette section spécifie les tâches à réaliser à chaque jour en mode ‘temps réel’ exécutées en tant que tâche horaire cron. Utilisez pour des choses qui ne changent pas très souvent, tel que les graphes mensuels ou annuels.

`services` est une liste de ‘services’ auxquels envoyer vos données. Chaque service listé doit avoir un fichier de configuration dans le dossier `pywws/services/`. Voir pywws.toservice pour plus de détails.

`twitter` est une liste de gabarit texte à traiter avant de les poster sur Twitter.

`text` et `plot` sont des listes de gabarits texte et graphe à traiter et à téléverser sur votre site web.

## ftp: configuration du téléversement à un site web

    [ftp]
    local site = False
    secure = False
    site = ftp.your_isp.co.uk
    user = username
    password = userpassword
    directory = public_html/weather/data/

Ces entrées fournissent des détails sur votre site web (ou répertoire local) où doivent être transférés les fichier de texte et de graphe traités.

`local site` spécifie si les fichiers doivent être copiés dans un dossier local ou envoyé sur un site distant. Vous pouvez vouloir fixer ce paramètre si votre serveur web fonctionne sur le même ordinateur qui exécute pywws.

`secure` spécifie si le transfert des fichiers utilise SFTP (FTP sécurisé) au lieu de l’habituel FTP. Votre hébergeur doit être en mesure de vous dire si vous pouvez utiliser SFTP.

`site` est l’adresse web de votre site FTP à laquelle transférer vos fichiers.

`user` et `password` sont les informations de branchement pour votre site FTP. Votre hébergeur doit vous avoir fourni ces informations.

`directory` spécifie où sur le site FTP (ou le disque local) les fichiers doivent être envoyés. Notez que vous pourriez devoir expérimenter quelque peu - vous pourriez par exemple devoir utiliser un caractère ‘/’ au début de votre adresse.

## twitter: configuration pour poster sur Twitter

    [twitter]
    secret = longstringofrandomcharacters
    key = evenlongerstringofrandomcharacters
    latitude = 51.365
    longitude = -0.251

`secret` et `key` sont les données d’authentification fournies par Twitter. Pour les configurer, exécutez le programme `TwitterAuth.py`.

`latitude` et `longitude` sont vos données de localisation et sont optionnelles. Si vous les incluez dans vos ‘tweets météo’ vos utilisateurs pourront voir où est située votre station. Ce qui pourrait aider les utilisateurs à trouver votre station s’ils cherchent par localisation.

## underground, metoffice, temperaturnu etc: configuration pour poster sur ces ‘services’

    [underground]
    station = IXYZABA5
    password = secret

Ces sections contiennent l’information nécessaire pour envoyer vos données sur ces services météo, tel que mot de passe et ID de votre station. Le nom de ces entrées de données dépend du service. L’exemple montré affiche les informations pour Weather Underground.

`station` est le PWS ID (Identificateur de station) alloué à la station météo par Weather Underground.

`password` est votre mot de passe pour Weather Underground.

# status.ini - status file format

This file is written by pywws and should not (usually) be edited. The following sections are currently in use:

> - fixed: valeurs copiées à partir des “blocs fixes” de la station météo.
> - clock: synchronisation information.
> - last update: date and time of most recent task completions.

## fixed: valeurs copiées à partir des “blocs fixes” de la station météo

    [fixed]
    pressure offset = 7.4
    fixed block = {...}

`pressure offset` is the difference between absolute and relative air pressure. It is copied from the weather station, assuming you have set it up to display the correct relative pressure.

`fixed block` is all the data stored in the first 256 bytes of the station’s memory. This includes maximum and minimum values, alarm threshold settings, display units and so on.

## clock: synchronisation information

    [clock]
    station = 1360322930.02
    sensor = 1360322743.69

These values record the measured times when the station’s clock logged some data and when the outside sensors transmitted a new set of data. They are used to try and prevent the USB interface crashing if the computer accesses the weather station at the same time as either of these events, a common problem with many EasyWeather compatible stations. The times are measured every 24 hours to allow for drift in the clocks.

## last update: date and time of most recent task completions

    [last update]
    hourly = 2013-05-30 19:04:15
    logged = 2013-05-30 19:04:15
    daily = 2013-05-30 09:04:15
    openweathermap = 2013-05-30 18:59:15
    underground = 2013-05-30 18:58:34
    metoffice = 2013-05-30 18:59:15
    12 hourly = 2013-05-30 09:04:15

These record date & time of the last successful completion of various tasks. They are used to allow unsuccessful tasks (e.g. network failure preventing uploads) to be retried after a few minutes.

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Guides utilisateur »